gold_corpus = """
<div class="col-md-6">
    <h2>Gold</h2>
    <p class="text-column">{gold_html}</p>
</div>
"""
